@@ -230,9 +230,9 @@ class MyWhatify:
                     notes='created from Automation, run minutes: ' + str(training_time_in_minutes),
                     ensemble_size=ensemble_size,
                     n_folds=cv_folds,
-                    max_models_num=max_models_num,
+                    max_models_num=int(max_models_num) if max_models_num else max_models_num,
                     interpretability_level=interpretability_level,
-                    timeout=training_time_in_minutes * 60, wait=wait, skip_if_exists=skip_if_exists
+                    timeout=int(training_time_in_minutes) * 60, wait=wait, skip_if_exists=skip_if_exists
                 )
                 task_id = task['id']
                 ret_dict = task.to_dict()
